@@ -3,13 +3,9 @@ package BookShelf;
 use strict;
 use warnings;
 
-#
-# Set flags and add plugins for the application
-#
-#         -Debug: activates the debug mode for very useful log messages
-# Static::Simple: will serve static files from the applications root directory
-#
-use Catalyst qw/-Debug Static::Simple DefaultEnd FormValidator/;
+
+#-Debug 
+use Catalyst qw/Static::Simple DefaultEnd FormValidator/;
 
 our $VERSION = '0.01';
 
