@@ -4,17 +4,25 @@ use base 'Catalyst::Enzyme::CRUD::Controller';
 use strict;
 use warnings;
 
+
+
 =head1 NAME
 
-BookShelf::Controller::Borrower - Catalyst Controller
+BookShelf::Controller::Borrower - Catalyst Enzyme CRUD Controller
+
+
 
 =head1 SYNOPSIS
 
 See L<BookShelf>
 
+
+
 =head1 DESCRIPTION
 
-Catalyst Controller.
+Catalyst Enzyme Controller with CRUD support.
+
+
 
 =head1 METHODS
 
@@ -27,16 +35,25 @@ sub model_class {
     return("BookShelf::Model::BookShelfDB::Borrower");
 }
 
-        
+
+
+=head1 SEE ALSO
+
+L<BookShelf>, L<Catalyst::Enzyme::CRUD::Controller>,
+L<Catalyst::Enzyme>
+
+
 
 =head1 AUTHOR
 
 A clever guy
 
+
+
 =head1 LICENSE
 
-This library is free software, you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This library is free software . You can redistribute it and/or modify
+it under the same terms as perl itself.
 
 =cut
 
